@@ -2,9 +2,9 @@ import logging
 import os
 import sys
 
-__version__ = '0.7.2'
+__version__ = '0.7.3'
 
-level = logging.WARNING
+level = logging.INFO
 if 'WHIPPER_DEBUG' in os.environ:
     level = os.environ['WHIPPER_DEBUG'].upper()
 if 'WHIPPER_LOGFILE' in os.environ:
