@@ -22,12 +22,12 @@ import argparse
 import cdio
 import os
 import glob
-import sys
 import logging
 from whipper.command.basecommand import BaseCommand
 from whipper.common import (
     accurip, config, drive, program, task
 )
+from whipper.common.common import validate_template
 from whipper.program import cdrdao, cdparanoia, utils
 from whipper.result import result
 
@@ -83,29 +83,28 @@ class _CD(BaseCommand):
     def do(self):
         self.config = config.Config()
         self.program = program.Program(self.config,
-                                       record=self.options.record,
-                                       stdout=sys.stdout)
+                                       record=self.options.record)
         self.runner = task.SyncRunner()
 
         # if the device is mounted (data session), unmount it
         self.device = self.options.device
-        sys.stdout.write('Checking device %s\n' % self.device)
+        logger.info('checking device %s', self.device)
 
         utils.load_device(self.device)
         utils.unmount_device(self.device)
 
         # first, read the normal TOC, which is fast
-        print("Reading TOC...")
+        logger.info("reading TOC...")
         self.ittoc = self.program.getFastToc(self.runner, self.device)
 
         # already show us some info based on this
         self.program.getRipResult(self.ittoc.getCDDBDiscId())
-        sys.stdout.write("CDDB disc id: %s\n" % self.ittoc.getCDDBDiscId())
+        print("CDDB disc id: %s" % self.ittoc.getCDDBDiscId())
         self.mbdiscid = self.ittoc.getMusicBrainzDiscId()
-        sys.stdout.write("MusicBrainz disc id %s\n" % self.mbdiscid)
+        print("MusicBrainz disc id %s" % self.mbdiscid)
 
-        sys.stdout.write("MusicBrainz lookup URL %s\n" %
-                         self.ittoc.getMusicBrainzSubmitURL())
+        print("MusicBrainz lookup URL %s" %
+              self.ittoc.getMusicBrainzSubmitURL())
 
         self.program.metadata = (
             self.program.getMusicBrainz(self.ittoc, self.mbdiscid,
@@ -119,12 +118,12 @@ class _CD(BaseCommand):
             cddbid = self.ittoc.getCDDBValues()
             cddbmd = self.program.getCDDB(cddbid)
             if cddbmd:
-                sys.stdout.write('FreeDB identifies disc as %s\n' % cddbmd)
+                logger.info('FreeDB identifies disc as %s', cddbmd)
 
             # also used by rip cd info
             if not getattr(self.options, 'unknown', False):
                 logger.critical("unable to retrieve disc metadata, "
-                                "--unknown not passed")
+                                "--unknown argument not passed")
                 return -1
 
         self.program.result.isCdr = cdrdao.DetectCdr(self.device)
@@ -134,11 +133,21 @@ class _CD(BaseCommand):
                             "--cdr not passed")
             return -1
 
+        # Change working directory before cdrdao's task
+        if self.options.working_directory is not None:
+            os.chdir(os.path.expanduser(self.options.working_directory))
+        out_bpath = self.options.output_directory.decode('utf-8')
+        # Needed to preserve cdrdao's tocfile
+        out_fpath = self.program.getPath(out_bpath,
+                                         self.options.disc_template,
+                                         self.mbdiscid,
+                                         self.program.metadata)
         # now, read the complete index table, which is slower
         self.itable = self.program.getTable(self.runner,
                                             self.ittoc.getCDDBDiscId(),
                                             self.ittoc.getMusicBrainzDiscId(),
-                                            self.device, self.options.offset)
+                                            self.device, self.options.offset,
+                                            out_fpath)
 
         assert self.itable.getCDDBDiscId() == self.ittoc.getCDDBDiscId(), \
             "full table's id %s differs from toc id %s" % (
@@ -167,7 +176,7 @@ class _CD(BaseCommand):
                 self.program.result.cdparanoiaDefeatsCache = \
                     self.config.getDefeatsCache(*info)
             except KeyError as e:
-                logger.debug('Got key error: %r' % (e, ))
+                logger.debug('got key error: %r', (e, ))
         self.program.result.artist = self.program.metadata \
             and self.program.metadata.artist \
             or 'Unknown Artist'
@@ -225,8 +234,7 @@ Log files will log the path to tracks relative to this directory.
         if info:
             try:
                 default_offset = config.Config().getReadOffset(*info)
-                sys.stdout.write("Using configured read offset %d\n" %
-                                 default_offset)
+                logger.info("using configured read offset %d", default_offset)
             except KeyError:
                 pass
 
@@ -235,8 +243,8 @@ Log files will log the path to tracks relative to this directory.
         self.parser.add_argument('-L', '--logger',
                                  action="store", dest="logger",
                                  default='whipper',
-                                 help="logger to use (choose from '"
-                                 "', '".join(loggers) + "')")
+                                 help=("logger to use (choose from: '%s" %
+                                       "', '".join(loggers) + "')"))
         # FIXME: get from config
         self.parser.add_argument('-o', '--offset',
                                  action="store", dest="offset",
@@ -285,7 +293,9 @@ Log files will log the path to tracks relative to this directory.
 
         self.options.track_template = self.options.track_template.decode(
             'utf-8')
+        validate_template(self.options.track_template, 'track')
         self.options.disc_template = self.options.disc_template.decode('utf-8')
+        validate_template(self.options.disc_template, 'disc')
 
         if self.options.offset is None:
             raise ValueError("Drive offset is unconfigured.\n"
@@ -324,26 +334,24 @@ Log files will log the path to tracks relative to this directory.
             if logs:
                 msg = ("output directory %s is a finished rip" %
                        dirname.encode('utf-8'))
-                logger.critical(msg)
+                logger.debug(msg)
                 raise RuntimeError(msg)
-            else:
-                sys.stdout.write("output directory %s already exists\n" %
-                                 dirname.encode('utf-8'))
         else:
-            print("creating output directory %s" % dirname.encode('utf-8'))
+            logger.info("creating output directory %s",
+                        dirname.encode('utf-8'))
             os.makedirs(dirname)
 
         # FIXME: turn this into a method
 
         def _ripIfNotRipped(number):
-            logger.debug('ripIfNotRipped for track %d' % number)
+            logger.debug('ripIfNotRipped for track %d', number)
             # we can have a previous result
             trackResult = self.program.result.getTrackResult(number)
             if not trackResult:
                 trackResult = result.TrackResult()
                 self.program.result.tracks.append(trackResult)
             else:
-                logger.debug('ripIfNotRipped have trackresult, path %r' %
+                logger.debug('ripIfNotRipped have trackresult, path %r',
                              trackResult.filename)
 
             path = self.program.getPath(self.program.outdir,
@@ -351,7 +359,7 @@ Log files will log the path to tracks relative to this directory.
                                         self.mbdiscid,
                                         self.program.metadata,
                                         track_number=number) + '.flac'
-            logger.debug('ripIfNotRipped: path %r' % path)
+            logger.debug('ripIfNotRipped: path %r', path)
             trackResult.number = number
 
             assert isinstance(path, unicode), "%r is not unicode" % path
@@ -368,18 +376,18 @@ Log files will log the path to tracks relative to this directory.
                 if path != trackResult.filename:
                     # the path is different (different name/template ?)
                     # but we can copy it
-                    logger.debug('previous result %r, expected %r' % (
-                        trackResult.filename, path))
+                    logger.debug('previous result %r, expected %r',
+                                 trackResult.filename, path)
 
-                sys.stdout.write('Verifying track %d of %d: %s\n' % (
-                    number, len(self.itable.tracks),
-                    os.path.basename(path).encode('utf-8')))
+                logger.info('verifying track %d of %d: %s',
+                            number, len(self.itable.tracks),
+                            os.path.basename(path).encode('utf-8'))
                 if not self.program.verifyTrack(self.runner, trackResult):
-                    sys.stdout.write('Verification failed, reripping...\n')
+                    logger.warning('verification failed, reripping...')
                     os.unlink(path)
 
             if not os.path.exists(path):
-                logger.debug('path %r does not exist, ripping...' % path)
+                logger.debug('path %r does not exist, ripping...', path)
                 tries = 0
                 # we reset durations for test and copy here
                 trackResult.testduration = 0.0
@@ -389,9 +397,9 @@ Log files will log the path to tracks relative to this directory.
                     tries += 1
                     if tries > 1:
                         extra = " (try %d)" % tries
-                    sys.stdout.write('Ripping track %d of %d%s: %s\n' % (
-                        number, len(self.itable.tracks), extra,
-                        os.path.basename(path).encode('utf-8')))
+                    logger.info('ripping track %d of %d%s: %s',
+                                number, len(self.itable.tracks), extra,
+                                os.path.basename(path).encode('utf-8'))
                     try:
                         logger.debug('ripIfNotRipped: track %d, try %d',
                                      number, tries)
@@ -399,7 +407,7 @@ Log files will log the path to tracks relative to this directory.
                                               offset=int(self.options.offset),
                                               device=self.device,
                                               taglist=self.program.getTagList(
-                                                  number),
+                                                  number, self.mbdiscid),
                                               overread=self.options.overread,
                                               what='track %d of %d%s' % (
                                                   number,
@@ -407,43 +415,37 @@ Log files will log the path to tracks relative to this directory.
                                                   extra))
                         break
                     except Exception as e:
-                        logger.debug('Got exception %r on try %d',
-                                     e, tries)
+                        logger.debug('got exception %r on try %d', e, tries)
 
                 if tries == MAX_TRIES:
-                    logger.critical('Giving up on track %d after %d times' % (
-                        number, tries))
+                    logger.critical('giving up on track %d after %d times',
+                                    number, tries)
                     raise RuntimeError(
                         "track can't be ripped. "
                         "Rip attempts number is equal to 'MAX_TRIES'")
                 if trackResult.testcrc == trackResult.copycrc:
-                    sys.stdout.write('CRCs match for track %d\n' % number)
+                    logger.info('CRCs match for track %d', number)
                 else:
                     raise RuntimeError(
-                        "CRCs did not match for track %d\n" % number
+                        "CRCs did not match for track %d" % number
                     )
 
-                sys.stdout.write(
-                    'Peak level: {}\n'.format(trackResult.peak))
-
-                sys.stdout.write(
-                    'Rip quality: {:.2%}\n'.format(trackResult.quality))
+                print('Peak level: %.6f' % (trackResult.peak / 32768.0))
+                print('Rip quality: {:.2%}'.format(trackResult.quality))
 
             # overlay this rip onto the Table
             if number == 0:
                 # HTOA goes on index 0 of track 1
                 # ignore silence in PREGAP
                 if trackResult.peak == SILENT:
-                    logger.debug(
-                        'HTOA peak %r is equal to the SILENT '
-                        'threshold, disregarding', trackResult.peak)
+                    logger.debug('HTOA peak %r is equal to the SILENT '
+                                 'threshold, disregarding', trackResult.peak)
                     self.itable.setFile(1, 0, None,
                                         self.ittoc.getTrackStart(1), number)
-                    logger.debug('Unlinking %r', trackResult.filename)
+                    logger.debug('unlinking %r', trackResult.filename)
                     os.unlink(trackResult.filename)
                     trackResult.filename = None
-                    sys.stdout.write(
-                        'HTOA discarded, contains digital silence\n')
+                    logger.info('HTOA discarded, contains digital silence')
                 else:
                     self.itable.setFile(1, 0, trackResult.filename,
                                         self.ittoc.getTrackStart(1), number)
@@ -457,14 +459,15 @@ Log files will log the path to tracks relative to this directory.
         htoa = self.program.getHTOA()
         if htoa:
             start, stop = htoa
-            print('found Hidden Track One Audio from frame %d to %d' % (
-                  start, stop))
+            logger.info('found Hidden Track One Audio from frame %d to %d',
+                        start, stop)
             _ripIfNotRipped(0)
 
         for i, track in enumerate(self.itable.tracks):
             # FIXME: rip data tracks differently
             if not track.audio:
-                print('skipping data track %d, not implemented' % (i + 1))
+                logger.warning('skipping data track %d, not implemented',
+                               i + 1)
                 # FIXME: make it work for now
                 track.indexes[1].relative = 0
                 continue
@@ -479,7 +482,7 @@ Log files will log the path to tracks relative to this directory.
         try:
             self.program.verifyImage(self.runner, self.ittoc)
         except accurip.EntryNotFound:
-            print('AccurateRip entry not found')
+            logger.warning('AccurateRip entry not found')
 
         accurip.print_report(self.program.result)
 
