@@ -22,6 +22,7 @@
 import os
 import os.path
 import math
+import re
 import subprocess
 import unicodedata
 
@@ -262,8 +263,8 @@ def getRelativePath(targetPath, collectionPath):
 
     Used to determine the path to use in .cue/.m3u files
     """
-    logger.debug('getRelativePath: target %r, collection %r' % (
-        targetPath, collectionPath))
+    logger.debug('getRelativePath: target %r, collection %r',
+                 targetPath, collectionPath)
 
     targetDir = os.path.dirname(targetPath)
     collectionDir = os.path.dirname(collectionPath)
@@ -274,12 +275,24 @@ def getRelativePath(targetPath, collectionPath):
         rel = os.path.relpath(
             targetDir + os.path.sep,
             collectionDir + os.path.sep)
-        logger.debug(
-            'getRelativePath: target and collection in different dir, %r' % rel
-        )
+        logger.debug('getRelativePath: target and collection '
+                     'in different dir, %r', rel)
         return os.path.join(rel, os.path.basename(targetPath))
 
 
+def validate_template(template, kind):
+    """
+    Raise exception if disc/track template includes invalid variables
+    """
+    if kind == 'disc':
+        matches = re.findall(r'%[^A,R,S,X,d,r,x,y]', template)
+    elif kind == 'track':
+        matches = re.findall(r'%[^A,R,S,X,a,d,n,r,s,t,x,y]', template)
+    if '%' in template and matches:
+        raise ValueError(kind + ' template string contains invalid '
+                         'variable(s): {}'.format(', '.join(matches)))
+
+
 class VersionGetter(object):
     """
     I get the version of a program by looking for it in command output
