@@ -54,7 +54,7 @@ class Popen(subprocess.Popen):
             except ValueError:
                 return self._close('stdin')
             except (subprocess.pywintypes.error, Exception), why:
-                if why[0] in (109, errno.ESHUTDOWN):
+                if why.args[0] in (109, errno.ESHUTDOWN):
                     return self._close('stdin')
                 raise
 
@@ -75,7 +75,7 @@ class Popen(subprocess.Popen):
             except ValueError:
                 return self._close(which)
             except (subprocess.pywintypes.error, Exception), why:
-                if why[0] in (109, errno.ESHUTDOWN):
+                if why.args[0] in (109, errno.ESHUTDOWN):
                     return self._close(which)
                 raise
 
@@ -95,7 +95,7 @@ class Popen(subprocess.Popen):
             try:
                 written = os.write(self.stdin.fileno(), input)
             except OSError, why:
-                if why[0] == errno.EPIPE:  # broken pipe
+                if why.args[0] == errno.EPIPE:  # broken pipe
                     return self._close('stdin')
                 raise
 
@@ -167,10 +167,10 @@ if __name__ == '__main__':
         shell, commands, tail = ('sh', ('ls', 'echo HELLO WORLD'), '\n')
 
     a = Popen(shell, stdin=PIPE, stdout=PIPE)
-    print recv_some(a),
+    print(recv_some(a))
     for cmd in commands:
         send_all(a, cmd + tail)
-        print recv_some(a),
+        print(recv_some(a))
     send_all(a, 'exit' + tail)
-    print recv_some(a, e=0)
+    print(recv_some(a, e=0))
     a.wait()
