@@ -18,6 +18,7 @@
 # You should have received a copy of the GNU General Public License
 # along with whipper.  If not, see <http://www.gnu.org/licenses/>.
 
+from __future__ import print_function
 import logging
 import sys
 
@@ -166,7 +167,8 @@ class Task(LogStub):
                 value >= 1.0 or value == 0.0):
             self.progress = value
             self._notifyListeners('progressed', value)
-            self.log('notifying progress: %r on %r', value, self.description)
+            self.debug('notifying progress: %r on %r',
+                       value, self.description)
 
     def setDescription(self, description):
         if description != self.description:
@@ -366,23 +368,23 @@ class BaseMultiTask(Task, ITaskListener):
         Subclasses should chain up to me at the end of their implementation.
         They should fall through to chaining up if there is an exception.
         """
-        self.log('BaseMultiTask.stopped: task %r (%d of %d)',
-                 task, self.tasks.index(task) + 1, len(self.tasks))
+        self.debug('BaseMultiTask.stopped: task %r (%d of %d)',
+                   task, self.tasks.index(task) + 1, len(self.tasks))
         if task.exception:
-            self.log('BaseMultiTask.stopped: exception %r',
-                     task.exceptionMessage)
+            self.warning('BaseMultiTask.stopped: exception %r',
+                         task.exceptionMessage)
             self.exception = task.exception
             self.exceptionMessage = task.exceptionMessage
             self.stop()
             return
 
         if self._task == len(self.tasks):
-            self.log('BaseMultiTask.stopped: all tasks done')
+            self.debug('BaseMultiTask.stopped: all tasks done')
             self.stop()
             return
 
         # pick another
-        self.log('BaseMultiTask.stopped: pick next task')
+        self.debug('BaseMultiTask.stopped: pick next task')
         self.schedule(0, self.next)
 
 
@@ -511,8 +513,8 @@ class SyncRunner(TaskRunner, ITaskListener):
     def schedule(self, task, delta, callable, *args, **kwargs):
         def c():
             try:
-                self.log('schedule: calling %r(*args=%r, **kwargs=%r)',
-                         callable, args, kwargs)
+                self.debug('schedule: calling %r(*args=%r, **kwargs=%r)',
+                           callable, args, kwargs)
                 callable(*args, **kwargs)
                 return False
             except Exception as e:
@@ -521,8 +523,8 @@ class SyncRunner(TaskRunner, ITaskListener):
                 task.setException(e)
                 self.stopped(task)
                 raise
-        self.log('schedule: scheduling %r(*args=%r, **kwargs=%r)',
-                 callable, args, kwargs)
+        self.debug('schedule: scheduling %r(*args=%r, **kwargs=%r)',
+                   callable, args, kwargs)
 
         gobject.timeout_add(int(delta * 1000L), c)
 
@@ -539,15 +541,15 @@ class SyncRunner(TaskRunner, ITaskListener):
                     self._task.description, 100.0))
             else:
                 # clear with whitespace
-                sys.stdout.write("%s\r" % (' ' * self._longest, ))
+                print(("%s\r" % (' ' * self._longest, )), end='')
 
     def _output(self, what, newline=False, ret=True):
-        sys.stdout.write(what)
-        sys.stdout.write(' ' * (self._longest - len(what)))
+        print(what, end='')
+        print((' ' * (self._longest - len(what))), end='')
         if ret:
-            sys.stdout.write('\r')
+            print('\r', end='')
         if newline:
-            sys.stdout.write('\n')
+            print('')
         sys.stdout.flush()
         if len(what) > self._longest:
             self._longest = len(what)
