@@ -13,18 +13,18 @@ class FilterTestCase(common.TestCase):
 
     def testSlash(self):
         part = u'A Charm/A Blade'
-        self.assertEquals(self._filter.filter(part), u'A Charm-A Blade')
+        self.assertEqual(self._filter.filter(part), u'A Charm-A Blade')
 
     def testFat(self):
         part = u'A Word: F**k you?'
-        self.assertEquals(self._filter.filter(part), u'A Word - F__k you_')
+        self.assertEqual(self._filter.filter(part), u'A Word - F__k you_')
 
     def testSpecial(self):
         part = u'<<< $&*!\' "()`{}[]spaceship>>>'
-        self.assertEquals(self._filter.filter(part),
-                          u'___ _____ ________spaceship___')
+        self.assertEqual(self._filter.filter(part),
+                         u'___ _____ ________spaceship___')
 
     def testGreatest(self):
         part = u'Greatest Ever! Soul: The Definitive Collection'
-        self.assertEquals(self._filter.filter(part),
-                          u'Greatest Ever_ Soul - The Definitive Collection')
+        self.assertEqual(self._filter.filter(part),
+                         u'Greatest Ever_ Soul - The Definitive Collection')
